diff --git a/chicken-install.scm b/chicken-install.scm
index 7bc6041..60e39c7 100644
--- a/chicken-install.scm
+++ b/chicken-install.scm
@@ -97,6 +97,7 @@
   (define *csc-features* '())
   (define *csc-nonfeatures* '())
   (define *prefix* #f)
+  (define *no-install-deps* #f)
   (define *aliases* '())
   (define *cross-chicken* (feature? #:cross-chicken))
   (define *host-extension* *cross-chicken*)
@@ -114,7 +115,7 @@
 	*prefix*
 	(if (and *cross-chicken* (not *host-extension*))
 	    (make-pathname C_TARGET_LIB_HOME (sprintf "chicken/~a" C_BINARY_VERSION))
-	    (if *prefix*
+	    (if (and *prefix* (not *no-install-deps*))
 		(make-pathname
 		 *prefix*
 		 (sprintf "lib/chicken/~a" (##sys#fudge 42)))
@@ -814,6 +815,7 @@ usage: chicken-install [OPTION | EXTENSION[:VERSION]] ...
   -r   -retrieve                only retrieve egg into current directory, don't install
   -n   -no-install              do not install, just build (implies `-keep')
   -p   -prefix PREFIX           change installation prefix to PREFIX
+       -no-install-deps         do not install dependencies (only valid with -prefix)
        -list                    list extensions available over selected transport and location
        -host                    when cross-compiling, compile extension only for host
        -target                  when cross-compiling, compile extension only for target
@@ -953,6 +955,9 @@ EOF
 				(normalize-pathname 
 				 (make-pathname (current-directory) p) ) ) ) )
                         (loop (cddr args) eggs))
+		       ((string=? arg "-no-install-deps")
+			(set! *no-install-deps* #t)
+			(loop (cdr args) eggs))
                        ((or (string=? arg "-n") (string=? arg "-no-install"))
                         (set! *keep* #t)
                         (set! *no-install* #t)
@@ -1071,7 +1076,12 @@ EOF
 			    (irregex-match-substring m 1)
 			    (irregex-match-substring m 2)
 			    eggs))))
-                       (else (loop (cdr args) (cons arg eggs))))))))))
+                       (else (loop (cdr args) (cons arg eggs))))))))
+      (when (and *no-install-deps* (not *prefix*))
+	(with-output-to-port (current-error-port)
+	  (lambda ()
+	    (print "-no-install-deps only makes sense if used with -prefix.")))
+	(exit 1))))
 
   (register-feature! 'chicken-install)
 
